# tree-sitter-fasta

[![CI][ci]](https://github.com/will-gebbie/tree-sitter-fasta/actions/workflows/ci.yml)
[![crates][crates]](https://crates.io/crates/tree-sitter-fasta)
[![npm][npm]](https://www.npmjs.com/package/tree-sitter-fasta)
[![pypi][pypi]](https://pypi.org/project/tree-sitter-fasta)

fasta grammar for [tree-sitter](https://github.com/tree-sitter).

#### References

[FASTA file format](https://en.wikipedia.org/wiki/FASTA_format)

#### Supported File Extensions

- .fasta
- .faa
- .fna
- .ffn
- .fa
- .frn
- .fas
- .mpfa

[ci]: https://github.com/will-gebbie/tree-sitter-fasta/actions/workflows/ci.yml/badge.svg
[npm]: https://img.shields.io/npm/v/tree-sitter-fasta?logo=npm
[crates]: https://img.shields.io/crates/v/tree-sitter-fasta?logo=rust
[pypi]: https://img.shields.io/pypi/v/tree-sitter-fasta?logo=pypi&logoColor=ffd242
